ExternalStorage

Trait ExternalStorage 

pub trait ExternalStorage: Send + Sync {
    // Required method
    fn upload(
        &self,
        ipc_bytes: &[u8],
        compression: Compression,
    ) -> Result<UploadResult>;
}
Pluggable storage backend. Implementations upload Arrow IPC bytes and return a fetchable URL.

Kept synchronous to preserve compatibility with the current pipe/unix dispatch loop; async-only backends should offload via a blocking thread pool.

Required Methods

fn upload( &self, ipc_bytes: &[u8], compression: Compression, ) -> Result<UploadResult>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors